% ---------------------------------------------------------------
% B=ChebyshevBasis(b,n)
%
% Returns the base matrix to get the Chebyshev projection of an image.
% This base matrix can be later used in the Project/Reconstruct functions.
%
% The notation 'b' and 'n' corresponds to the one used in the Project
% function. 'b' are the columns/rows of the input image and 'n' are the
% rows/columns of the coefficicient matrix.
%
% We generate the n Chebyshev vectors (one per column of B) and we evaluate then
% at the points 0..b-1.
%
% Comb is the extension of nchoosek implemented in Comb.m (also used in
% InverseMomentsBasis).
%
% Input parameters:
%       > b: rows of B (number of elements per vector)
%       > n: columns of B (number of vectors in the base)
% Output parameters:
%       > B: The base matrix
%
% ---------------------------------------------------------------
function B=ChebyshevBasis(b,n)
  B=zeros(b,n);

  for l=1:n
    nf=sqrt(nt(l-1,b)); % normalization factor
    for k=1:b
      B(k,l)=t(l-1,b,k-1)/nf;
    end
  end

% The Chebyshev polinomial of order n evaluated at x with x<b
function s=t(n,b,x)
  s=0;
  for k=0:n
    c1=Comb(b-1-k,n-k);
    c2=Comb(n+k,n);
    c3=Comb(x,k);
    s=s+((-1)^(n-k)*c1*c2*c3);
  end
  s=factorial(n)*s;

% Normalization factor for the Chebyshev polinomial of order n
% evaluated at b points [0..b-1]
function n=nt(n,b)
  n=factorial(2*n)*Comb(b+n,2*n+1);
