% ---------------------------------------------------------------
% C=CompressImage(I,F,t,n)
%
% Compresses an image I by compressing tiles of size txt
% using function F to optain n coefficients per tile.
%
% Input parameters:
%       > I: The matrix containing the image
%       > F: The function to use in the compression
%            Predefined functions are :
%                - MomentsBasis
%                - ChebyshevBasis
%                - FourierBasis
%                - HaarBasis
%       > t: size of the squared tiles in which  the image is decompressed
%            If the size of the image is not multiple of 't', part of the image
%            is not compressed.
%       > n: The number of coefficients to compute per tile.
%
% Output parameters
%       > C: The compression information that can be used later to decompress
%            the image (see DecompressImage.m)
%            In C we store
%               F: the function used in the compression.
%               t: the size of the tiles. From this we recover the original
%                  size of the image.
%               M: the compression coefficients per tile (a nxn matrix per tile).
%
% ---------------------------------------------------------------
function C=CompressImage(I,F,t,n);
  C.F=F;  % We store the function used in the compression
  C.t=t;  % and the size of the tiles

  [a,b]=size(I); % Size of the input image

  ac=fix(a/t); % Number of tiles in the rows of the image
  bc=fix(b/t); % Number of tiles in the columns of the image

  B1=feval(F,t,n); % this is the projection matrix.

  for k=1:ac
    i=(k-1)*t+1;
    for l=1:bc
      j=(l-1)*t+1;
      C.M{k,l}=Project(B1,I(i:i+t-1,j:j+t-1),B1);
    end
  end
