% ---------------------------------------------------------------
% I=DecompressImage(C,F)
%
% Decompresses an image I from the compress information C.
% If the function F is given then the decompression is done in
% a different base than taht used for compresion.
%
% See CompressImage.m for information about the compression structure.
%
% Input parameters:
%       > C: Compress information resulting from CompressImage
%       > F: Optionally, a decompression function different from that
%            used in the compression. This different decompression is
%            achieved applying lemma 2 on the paper.
%            Predefined functions are :
%                - MomentsBasis
%                - ChebyshevBasis
%                - FourierBasis
%                - HaarBasis
%
% Output parameters
%       > I: the decompressed image.
%
% ---------------------------------------------------------------
function I=DecompressImage(C,varargin);

  % We compute the de-projection matrix (B1) to be used for each tile.
  % In case the reconstruction is in a different base than the
  % construction, we compute also the alternative decompression basis (Ba)

  % The way in which we compute B1, Ba is the same as that in  ReconstrutF.m
  % (but here B2=B1 and Bb=Ba since we use squatre tiles and number of coefficients).

  % number of coefficients for each tile (we use squared coefficient matrices)
  n=size(C.M{1,1},1);

  if length(varargin)==1  % if the decompression is in a different basis than the compression.
    twoBasis=1;

    F2=varargin{1};
    Ba=feval(F2,C.t,n);
      % check the orthonormality
      Z=real(Ba' * Ba)- eye(n);
      if abs(max(Z(:)))>1e-6
        error('The base used for reconstruction must be orthonormal');
      end
  else
    twoBasis=0;
  end

  B1=feval(C.F,C.t,n);

  % number of tiles
  [ac,bc]=size(C.M);

  % size for the output image
  a=fix(ac*C.t);
  b=fix(bc*C.t);

  I=zeros(a,b);

  for k=1:ac
    i=(k-1)*C.t+1;
    for l=1:bc
      j=(l-1)*C.t+1;
      if twoBasis
        I(i:i+C.t-1,j:j+C.t-1)=Reconstruct2(Ba,B1,C.M{k,l},B1,Ba);
      else
        I(i:i+C.t-1,j:j+C.t-1)=Reconstruct(B1,C.M{k,l},B1);
      end
    end
  end
