% ---------------------------------------------------------------
% I=ReconstructF(a,b,P,F1,F2)
%
% Reconstruct an image I from the projection matrix P obtained with function F1.
% Input parameters:
%       > a: Number of rows for the resulting image
%       > b: Number of columns for the resulting image
%       > P: Projection matrix.
%       > F1: The function we used to generate the basis matrix.
%             Predefined functions are:
%                - MomentsBasis
%                - ChebyshevBasis
%                - FourierBasis
%                - HaarBasis
%             If you add other functions, the interface to call them must
%             (b,n) with b,n integers.
%       > F2: If this function is used we reconstruct the image in
%             basis matrix defined by F2 (that can be different from that
%             used in the compression). This reconstructin in a different
%             base is achieved using Lemma2 of the paper.
%             F2 must expand a orthonormal basis (i.e., the MomentsBasis can
%             not be used as F2).
%
% Output parameters:
%       > I: The reconstructed image
%            Matrix size (a,b)
%
% This function is just a convinience wrapping of the Reconstruct and Reconstruct2
% functions.
%
% Example of use:
%           I=ReconstructF(68,58,Pm,@MomentsBasis)
%           I=ReconstructF(68,58,Pm,@MomentsBasis,@FourierBasis)
%
% ---------------------------------------------------------------
function I=ReconstructF(a,b,P,F1,varargin)
  if length(varargin)==1
    % The reconstruct in a different base than the projection (Reconstruct2)
    F2=varargin{1};
    [m,n]=size(P);

    Ba=feval(F2,a,m);
    % check the orthonormality
      Z=real(Ba' * Ba)- eye(m);
      e=abs(max(Z(:)))/a;
      if e>1e-1
        error('The base used for reconstruction must be orthonormal (%f)',e);
      end

    if a~=b | m~=n
      Bb=feval(F2,b,n);
      % check the orthonormality
        Z=real(Bb' * Bb)- eye(n);
        e=abs(max(Z(:)))/b;
        if e>1e-1
          error('The base used for reconstruction must be orthonormal %f',e);
        end
    else
      Bb=Ba;
    end

    B1=feval(F1,a,m);
    if a~=b | m~=n
      B2=feval(F1,b,n);
    else
      B2=B1;
    end

    I=Reconstruct2(Ba,B1,P,B2,Bb);
  else
    % Reconstruct in the same base as the projection (Reconstruct)
    [m,n]=size(P);

    B1=feval(F1,a,m);
    if a~=b | m~=n
      B2=feval(F1,b,n);
    else
      B2=B1;
    end

    I=Reconstruct(B1,P,B2);
  end

